/*
	Armazenamento de textos e atributos em PPU - Versão 1.0
	Criado por: Alex Crispim/Web Developer - UNA-SUS/BSB
*/

/*---------Código-Padrão-para-Criação-de-Persistência-no-PPU--------*/
//Função que recebe o parâmetro "id" que é o nome da variável persistente no PPU(Ex: NAVIGATION, STATUS etc). Retorna a persistência da variável.
function criarPersistencia(id){
	let persistencia = unasus.pack.getPersistence(id);
	if(persistencia === undefined){
		persistencia = criarPersistenciaPadrao(id);
	}
	if(persistencia === null){
		return false;
	}
	return persistencia;
}
//Função que cria a base da persistência caso ainda não exista, recebe o parâmetro "id" que é o nome da variável persistente no PPU que se quer criar. Retorna a base da persistência criada.
function criarPersistenciaPadrao(id){
	var persistencia = {};
	unasus.pack.setPersistence(id, persistencia);
	return persistencia;
}
/*Função que grava os valores na variável persistente enviada.
Recebe como parâmetro 1º a instância da variável persistente, 2º o "id" da variável persistente e 3º o "valor" contendo o objeto a ser modificado*/
function gravarObjeto(persistencia, id, valor){
	if(persistencia === undefined || persistencia === null){
		persistencia = criarPersistenciaPadrao(id);
	}
	let objetos = [persistencia, valor],
	resultado =  objetos.reduce(function(r, o){
		Object.keys(o).forEach(function(k){
			r[k] = o[k];
		});
		return r;
	}, {});
	persistencia = resultado;
	unasus.pack.setPersistence(id, persistencia);
	return persistencia;
}
/*---------Fim-Código-Padrão--------*/

/*---------PPU-ANNOTATIONS--------*/
/*Recebe texto de caracteres e atributos para armazenamento dentro do PPU.*/

/*Função que deleta valores na variável do PPU.
Recebe como parâmetros o "tipo", o "id" e a "chave" da anotação gravada que será deletada. E a chave deve ser informada em formato de array, podendo ter um ou mais valores.*/
function deletarAnotacao(tipo, id, chave){
	id = criarID(tipo, id);//Cria um identificador para a persistência
	if(arguments.length !== 3){
		console.warn("Não foram enviados os parâmetros corretos para localizar a anotação, envie o 'tipo' da anotação, o 'id' e a 'chave'");
	} else {
		let anotacoes = unasus.pack.getPersistence(id);
		if(anotacoes === undefined || anotacoes === null){
			alert("Não foi possível deletar esta anotação, pois ela não foi encontrada em nossos registros.");
		} else {
			for (let i = 0; i < chave.length; i++){
				delete anotacoes[chave[i]];
			}
			unasus.pack.setPersistence(id, anotacoes);
		}
	}
}
/*Função que controla a leitura e gravação de texto das anotações.
Pode receber 2 ou 4 parâmetros. Quando recebidos o "tipo" e o "id" da anotação será retornada o valor do Json ligado aquele "id".
Se enviado o "tipo", "id", "texto" e o "limite" da anotação será realizada a gravação do texto com limite máximo especificado.*/
function usarAnotacaoPPU(tipo, id, texto, limiteMax){
	id = criarID(tipo, id);//Cria um identificador para a persistência
	//Verifica e cria a persistência do "id" enviado na variável do PPU
	let anotacoes = unasus.pack.getPersistence(id);
	//Verifica se foram enviados somente dois parâmetros para usar o recurso de leitura dos dados Json
	if(arguments.length === 2 && tipo && id){
		if(anotacoes === undefined || anotacoes === null){
			console.log("O objeto pesquisado não foi encontrado.");
			return;//Retorna por padrão undefined
		} else {
			return anotacoes;
		}
	}
	//Verifica se foram enviados os 4 parâmetros e se o "texto" possui caracteres para que possa realizar a gravação na variável PPU
	if(arguments.length === 4 && texto.length > 0){
		//Verifica o texto digitado e limita a quantidade de caracteres que serão gravados no formato Json do PPU
		if(texto.length > limiteMax){
			texto = texto.substring(0, limiteMax);
			alert("Foram enviados caracteres além do limite de "+limiteMax+" o texto só será gravado até o limite.");
		} else {
			texto = texto;
		}
		//Caso ainda não exista a persistência no PPU ela será criada ou somente adicionada a nova gravação.
		if(anotacoes === undefined || anotacoes === null){
			gravarObjeto(anotacoes, id, {texto: texto});
		} else {
			if(anotacoes.texto !== texto){
				let tipoAnotacao = anotacoes;
				//Concatena objetos caso já exista atributos no Json com o "id" enviado
				let objetos = [tipoAnotacao, {texto: texto}],
				resultado =  objetos.reduce(function(r, o){
					Object.keys(o).forEach(function(k){
						r[k] = o[k];
					});
					return r;
				}, {});
				tipoAnotacao = resultado;
				gravarObjeto(anotacoes, id, tipoAnotacao);
			} else {
				return false;
			}
		}
	} else {
		console.log("Não foram enviados dados para gravação.");
	}
	//Verifica se foram enviados os parâmetros necessários para leitura ou gravação
	if(!tipo && !id || !tipo && !id && !texto && !limiteMax){
		console.warn("A função anotacaoPPU não recebeu parâmetros suficientes, use 2 parâmetro para ler a anotação ou 4 para gravar uma anotação.");
	}
}
/*Função para gravação de atributos ao Json do PPU
Recebe 3 parâmetros: "tipo", "id" e o "valor" do novo atributo do identificador da anotação, o "valor" pode conter um objeto ou conjunto de objetos*/
function gravarAtributoAnotacao(tipo, id, valor){
	id = criarID(tipo, id);//Cria um identificador para a persistência
	//Verifica se todos os parâmetros foram enviados
	if(arguments.length !== 3){
		console.log("Não foram enviados parâmetros suficientes para a gravação de atributos no objeto, envie o 'tipo', o 'id' da anotação e o 'valor' do atributo.");
	} else {
		let anotacoes = unasus.pack.getPersistence(id);
		if(anotacoes === undefined || anotacoes === null){
			gravarObjeto(anotacoes, id, valor);
		} else {
			let tipoAnotacao = anotacoes;
			//Concatena objetos caso já exista atributos no Json com o "id" enviado
			let objetos = [tipoAnotacao, valor],
			resultado =  objetos.reduce(function(r, o){
				Object.keys(o).forEach(function(k){
					r[k] = o[k];
				});
				return r;
			}, {});
			tipoAnotacao = resultado;
			gravarObjeto(anotacoes, id, tipoAnotacao);
		}
	}
}

function criarID(tipo, id){
	var idUnico = tipo +"_"+ id;
	return idUnico;
}