/*
    Created by Alex Crispim/UNASUS
    Media Player
    Version: 1.0.2
*/

/*Player de Áudio*/
function playerAudioUNASUS() {
    let audioComponent = document.querySelectorAll(".audioComponent");//Localiza os componentes que possuem áudio.

    //Função que recebe o tempo em segundos e converte para o tempo desejado
    const timeConverter = (time) => {
        const minutes = Math.floor(time / 60);
        const seconds = Math.floor(time % 60);
        const processMinutes = minutes < 10 ? `0${minutes}` : `${minutes}`;
        const processSeconds = seconds < 10 ? `0${seconds}` : `${seconds}`;
        return `${processMinutes}:${processSeconds}`;
    }
    //Aceita vários componentes com Áudio em uma mesma página
    audioComponent.forEach(item => {
        let audio = item.querySelector(".audio");
        let seek = item.querySelector(".timeline");

        let btPlayPause = item.querySelector(".controllerAudio");
        let btSound = item.querySelector(".btSound");

        let displayCurrent = item.querySelector(".current");
        let displayDuration = item.querySelector('.duration');
        let displayVolume = item.querySelector('.displayVolume');
        let sound = item.querySelector(".displaySound");
        let volume = item.querySelector(".volume");

        if (audio.readyState > 0) {//Verifica o status do carregamento do áudio
            timeUpdate();
            setSliderMax();
            displayBufferedAmount();
        } else {
            audio.addEventListener("loadedmetadata", () => {
                timeUpdate();
                setSliderMax();
                displayBufferedAmount();
            });
        }
        volume.value = 100;
        audio.onloadedmetadata = function () {
            displayDuration.textContent = timeConverter(audio.duration);
        };
        btPlayPause.addEventListener("click", function () {
            let controllerAudio = this.closest(".audioPlayerUnasus").children[0];
            if (controllerAudio.paused) {
                controllerAudio.play();
                btPlayPause.classList.remove("play");
                btPlayPause.classList.add("pause");
            } else {
                controllerAudio.pause();
                btPlayPause.classList.remove("pause");
                btPlayPause.classList.add("play");
            }
        });
        audio.addEventListener("timeupdate", timeUpdate);
        function showRangeProgress (rangeInput){
            if (rangeInput === seek) seek.style.setProperty("--seek-before-width", rangeInput.value / rangeInput.max * 100 + '%');
            else volume.style.setProperty("--volume-before-width", rangeInput.value / rangeInput.max * 100 + '%');
        }
        function timeUpdate() {
            displayCurrent.textContent = timeConverter(audio.currentTime);
            seek.value = 100 * (audio.currentTime / audio.duration);
            seek.value = audio.currentTime;
            showRangeProgress(seek);
            if (audio.currentTime === audio.duration) {
                btPlayPause.classList.remove("pause");
                btPlayPause.classList.add("play");
                displayCurrent.textContent = "00:00";
                seek.value = 0;
            }
        }
        function setSliderMax() {
            seek.max = Math.floor(audio.duration);
        }
        function displayBufferedAmount (){
            //Mostra visualmente o carregamento do áudio
            if(audio.buffered.length > 0){
                const bufferedAmount = Math.floor(audio.buffered.end(audio.buffered.length - 1));
                seek.style.setProperty("--buffered-width", `${(bufferedAmount / seek.max) * 100}%`);
            }
        }
        audio.addEventListener("progress", displayBufferedAmount);
        seek.oninput = function () {
            displayCurrent.textContent = timeConverter(this.value);
            audio.currentTime = seek.value;
        }
        seek.addEventListener("input", (e) => {
            showRangeProgress(e.target);
        });
        seek.addEventListener("change", function () {
            if (!audio.paused) {
                seek.style.setProperty("--seek-before-width", `${seek.value / seek.max * 100}%`);
                showRangeProgress(seek.value);
            }
        });
        volume.oninput = function () {
            sound.textContent = this.value;
            audio.volume = this.value / 100;
            btSound.classList.toggle("mute", this.value == 0);
            btSound.classList.toggle("min", this.value > 0 && this.value < 50);
            btSound.classList.toggle("middle", this.value >= 50 && this.value < 100);
            btSound.classList.toggle("full", this.value == 100);
        }
        volume.addEventListener("input", (e) => {
            showRangeProgress(e.target);
        });

        btSound.addEventListener("click", function () {
            displayVolume.classList.remove("hide");
            displayVolume.classList.add("showController");
        });

        displayVolume.addEventListener("mouseleave", function(){
            hideVolume();
        });
        displayVolume.addEventListener("touchend", hideVolume);

        function hideVolume() {
            displayVolume.classList.remove("showController");
            displayVolume.classList.add("hide");
        }
    });
}