/*!
 * jQuery Conversas
 *
 * Copyright 2021–2021, Mateus MOura
 * Dual licensed under the MIT or GPL Version 2 licenses.
 *
 */


(function( $ ) {
  $.fn.Conversas = function() {
    let ID_FALA = '';

    function scrollFala(bloco) {
      var body = $("html, body");
      body.stop().animate({ scrollTop: bloco[0].offsetTop + 300 }, 300, 'swing');
    }

    function atualizarIndice(conversa) {
      const total = $('.bloco-conversas__fala', conversa).length;
      const totalAtivas = $('.bloco-conversas__fala-ativa', conversa).length;

      $('.bloco-atividade__footer-acoes p').text(`${totalAtivas} de ${total}`);
    }

    function mostrarTodasConversas(conversa) {
      $('.bloco-conversas__fala:not(".bloco-conversas__fala-ativa")', conversa).addClass('bloco-conversas__fala-ativa').fadeIn();
      $('.btn-iniciar, .btn-mostrarTodos, .btn-retomar, .btn-pause', conversa).hide();
      $('.btn-recomecar', conversa).show();
      $('.btn-anterior', conversa).removeClass('disabled');
      $('.btn-proximo', conversa).addClass('disabled');
      recomecar(conversa);

      atualizarIndice(conversa);
    }

    function proxima(conversa) {
      const falaAtiva = $('.bloco-conversas__fala-ativa:last', conversa);
      const proximaFala = falaAtiva.next('.bloco-conversas__fala');
      if (proximaFala) {
        proximaFala.fadeIn(function() {
          scrollFala(proximaFala)
        }).addClass('bloco-conversas__fala-ativa');
        $('.btn-anterior', conversa).removeClass('disabled');

        if (!proximaFala.next('.bloco-conversas__fala').length) {
          $('.btn-proximo', conversa).addClass('disabled');
          $('.btn-iniciar, .btn-mostrarTodos, .btn-retomar', conversa).hide();
          $('.btn-recomecar', conversa).show();
        }

        atualizarIndice(conversa);
      }
    }

    function anterior (conversa) {
      const falaAtiva = $('.bloco-conversas__fala-ativa:last', conversa);
      const falaAnterior = falaAtiva.prev('.bloco-conversas__fala');

      if (falaAnterior) {
        falaAtiva.removeClass('bloco-conversas__fala-ativa').hide();
        $('.btn-proximo', conversa).removeClass('disabled');
        $('.btn-recomecar, .btn-pausar, .btn-retomar', conversa).hide();
        $('.btn-iniciar, .btn-mostrarTodos', conversa).show();

        scrollFala(falaAnterior);

        if (!falaAnterior.prev('.bloco-conversas__fala').length) {
          $('.btn-anterior', conversa).addClass('disabled');
        }

        atualizarIndice(conversa);
      }
    }

    function recomecar(conversa) {
      $('.btn-pausar, .btn-retomar, .btn-mostrarTodos', conversa).hide();

      $('.btn-proximo', conversa).addClass('disabled');

      $('.bloco-atividade__footer .btn-recomecar', conversa).fadeIn().click(function() {
        $(this).hide();
        $('.bloco-conversas__fala', conversa).removeClass('bloco-conversas__fala-ativa').hide();
        $('.bloco-conversas__fala', conversa).first().addClass('bloco-conversas__fala-ativa').show();
        $('.btn-iniciar, .btn-mostrarTodos', conversa).show();
        $('.btn-proximo', conversa).removeClass('disabled');
        $('.btn-anterior', conversa).addClass('disabled');
        scrollFala($('.bloco-conversas__fala', conversa).first());

        atualizarIndice(conversa);
      });
    }

    function pausar (conversa) {
      clearTimeout(ID_FALA);

      $('.bloco-atividade__footer .btn-retomar', conversa).fadeIn().on('click', function() {
        $(this).hide();
        iniciar(conversa);
      })
    }

    function iniciar (conversa) {
      const ativa = $('.bloco-conversas__fala-ativa:last', conversa);

      $('.bloco-atividade__footer .disabled', conversa).removeClass('disabled');
      $('.bloco-atividade__footer .btn-pausar', conversa).fadeIn().on('click', function() {
        $(this).hide();
        pausar(conversa);
      });
      const proximaFala = ativa.next('.bloco-conversas__fala');
      const tempoProximo = proximaFala.next('.bloco-conversas__fala').data('tempo');

      if (!proximaFala) {
        recomecar(conversa);
      }

      proximaFala.fadeIn(function() {
        const $this = $(this);
        $this.addClass('bloco-conversas__fala-ativa');

        scrollFala(proximaFala);

        atualizarIndice(conversa);

        const mostrarProximaFala = function(fala, tempo) {
          ID_FALA = setTimeout(() => {
            fala.fadeIn(function() {
              const proxima = fala.next('.bloco-conversas__fala');
              fala.addClass('bloco-conversas__fala-ativa');

              scrollFala(fala);

              if (proxima.length) {
                mostrarProximaFala(proxima, proxima.data('tempo'))
              } else {
                recomecar(conversa);
              }

              atualizarIndice(conversa);
            })
          }, tempo)
        };

        mostrarProximaFala(proximaFala.next('.bloco-conversas__fala'), tempoProximo);
      });
    }

    function configuracoes (conversa) {
      $('.bloco-conversas__fala:first', conversa).addClass('bloco-conversas__fala-ativa');

      $('.btn-anterior', conversa).on('click', function() {
        anterior(conversa);
      });

      $('.btn-proximo', conversa).on('click', function() {
        proxima(conversa);
      });

      $('.btn-mostrarTodos', conversa).on('click', function() {
        $(this).hide();
        mostrarTodasConversas(conversa);
      });

      $('.btn-iniciar', conversa).on('click', function() {
        $(this).hide();
        iniciar(conversa)
      });
    }

    function init(elem) {
      $.each($(elem), function (index, value) {
        const conversa = $(value);

        configuracoes(conversa);
        atualizarIndice(conversa);
      })
    }

    init(this);

  };
}( jQuery ));
"use strict";

$(document).ready(function () {
  $('.bloco-conversas').Conversas();
});